@@ -76,64 +76,50 @@
 #                                                                             #
 ###############################################################################
 
-=encoding utf8
-
-=head1 NAME
-
-CracTools - A set of tools designed to extract data from CRAC's SAM files and to provide annotations.
-
-=cut 
-
 package CracTools;
-
-our $VERSION = '1.03';
-
+{
+  $CracTools::DIST = 'CracTools-core';
+}
+# ABSTRACT: A set of tools designed to extract data from CRAC's SAM files and to provide annotations.
+$CracTools::VERSION = '1.031';
 our $PACKAGE_NAME = "CracTools";
 
-=head1 AUTHORS
-
-Jérôme Audoux E<lt>L<jerome.audoux@univ-montp2.fr|mailto:jerome.audoux@univ-montp2.fr>E<gt>.
-Nicolas PHILIPPE E<lt>L<nicolas.philippe@inserm.fr|mailto:nicolas.philippe@inserm.fr>E<gt>.
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (C) 2012-2013 -- IRB/INSERM
-                           (Institut de Recherche en Biothérapie /
-                            Institut National de la Santé et de la
-                            Recherche Médicale)
-
-=head2 FRENCH
-
-Ce fichier fait partie de la suite CracTools qui contient plusieurs pipeline 
-intégrés permettant de traiter les évênements biologiques présents dans du 
-RNA-Seq. Les CracTools travaillent à partir d'un fichier SAM de CRAC et d'un 
-fichier d'annotation au format GFF3.
-
-Ce logiciel est régi  par la licence CeCILL  soumise au droit français et
-respectant les principes  de diffusion des logiciels libres.  Vous pouvez
-utiliser, modifier et/ou redistribuer ce programme sous les conditions de
-la licence CeCILL  telle que diffusée par le CEA,  le CNRS et l'INRIA sur
-le site "http://www.cecill.info".
-
-=head2 ENGLISH
-
-This file is part of the CracTools which provide several integrated 
-pipeline to analyze biological events present in RNA-Seq data. CracTools 
-work on a SAM file generated by CRAC and an annotation file in GFF3 format.
-
-This software is governed by the CeCILL license under French law and
-abiding by the rules of distribution of free software. You can use,
-modify and/ or redistribute the software under the terms of the CeCILL
-license as circulated by CEA, CNRS and INRIA at the following URL
-"http://www.cecill.info".
-
-=cut
-
-##############
-# End of POD #
-##############
-
 1; 
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+CracTools - A set of tools designed to extract data from CRAC's SAM files and to provide annotations.
+
+=head1 VERSION
+
+version 1.031
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Nicolas PHILIPPE <nicolas.philippe@inserm.fr>
+
+=item *
+
+Jérôme AUDOUX <jaudoux@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2014 by IRB/INSERM (Institut de Recherche en Biothérapie / Institut National de la Santé et de la Recherche Médicale).
+
+This is free software, licensed under:
+
+  CeCILL FREE SOFTWARE LICENSE AGREEMENT, Version 2.1 dated 2013-06-21
+
+=cut
