@@ -76,36 +76,13 @@
 #                                                                             #
 ###############################################################################
 
-=head1 NAME
-
-CracTools::Output - A module to manage CracTools output files.
-
-=head1 SYNOPSIS
-
-  # Creating a default output object.
-  # Everything will be print to the standard output
-  my $output = CracTools::Output->new();
-  
-  # Print nice headers
-  my $output->printHeaders(version => '1.01',summary => 'blabla', args => @ARGV);
-  
-  # This will print "foo\tbar\n"
-  $output->printLine('foo','bar');
-  
-  # Using semicolon as separator charcater
-  my $output = CracTools::Output->new(sep => ';');
-  
-  # Print into a file
-  my $output = CracTools::Output->new(file => 'foo.bar');
-
-=head1 DESCRIPTION
-
-CracTools::Output is a simple tool to generate Char-Separated files.
-
-=cut
 
 package CracTools::Output;
-
+{
+  $CracTools::Output::DIST = 'CracTools-core';
+}
+# ABSTRACT: A module to manage CracTools output files.
+$CracTools::Output::VERSION = '1.031';
 use strict;
 use warnings;
 
@@ -118,19 +95,6 @@ use constant DEFAULT_SEP => "\t";
 use strict;
 use warnings;
 
-=head1 METHODS
-
-=head2 new
-
-  Arg [sep]  : (Optional) Character to use as separator for columns
-  Arg [file] : (Optional) String - Ouput file, if not specified
-               CracTools::Output prints to STDOUT.
-
-  Example     : $output = CracTools::Output->new(file => 'output.txt', sep => '\t');
-  Description : Create a new CracTools::Output object
-  ReturnType  : CracTools::Output
-
-=cut
 
 sub new {
   my $class = shift;
@@ -155,15 +119,6 @@ sub new {
   return $self
 }
 
-=head2 printHeaders
-
-  Arg [version]  : (Optional) Version number of the script that is calling "printHeaders" method.
-  Arg [summary]  : (Optional) String - Summary text to print in headers (can have multiple lines
-
-  Example     : $output->printHeaders(version => $version, summary => "Found $n reads");
-  Description : Print headers to the output stream with CracTools-core version, date, name of calling script.
-
-=cut
 
 sub printHeaders {
   my $self = shift;
@@ -177,7 +132,7 @@ sub printHeaders {
   }
 
   $self->printlnOutput("# Date: ".localtime);
-  $self->printlnOutput("# Module: $CracTools::PACKAGE_NAME (v $CracTools::VERSION)");
+  $self->printlnOutput("# Module: $CracTools::DIST (v $CracTools::VERSION)");
   if(defined $version) {
     $self->printlnOutput("# Script: ".basename($0)." (v $version)");
   } else {
@@ -200,14 +155,6 @@ sub printHeaders {
   #$self->printlnOutput();
 }
 
-=head2 printHeaderLine
-
-  Arg [1] : Array of strings
-
-  Example     : $output->printHeaderLine("Read Id","Read_seq","Nb_occ");
-  Description : Print header line to the file (with a "# " append to the start of the line)
-
-=cut
 
 sub printHeaderLine {
   my $self = shift;
@@ -216,15 +163,6 @@ sub printHeaderLine {
   $self->printLine("# $first_field",@_);
 }
 
-=head2 printLine
-
-  Arg [1] : Array of strings
-
-  Example     : $output->printLine("Read Id","Read_seq","Nb_occ");
-  Description : Print a line to the file, each string of the array parameter is print
-                with the separator defined for the output.
-
-=cut
 
 sub printLine {
   my $self = shift;
@@ -236,14 +174,6 @@ sub printLine {
   $self->printlnOutput(join($self->{sep},@_));
 }
 
-=head2 printOutput
-
-  Arg [1] : String - Value to print
-
-  Example     : $output->printLine("This is a line");
-  Description : Print the string in parameter to the output stream.
-
-=cut
 
 sub printOutput {
   my $self = shift;
@@ -252,14 +182,6 @@ sub printOutput {
   print $stream $stuff;
 }
 
-=head2 printlnOutput
-
-  Arg [1] : String - Value to print
-
-  Example     : $output->printLine("This is a line");
-  Description : Print the string in parameter to the output stream with an extra "\n" at the end of the string.
-
-=cut
 
 sub printlnOutput {
   my $self = shift;
@@ -272,3 +194,112 @@ sub printlnOutput {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+CracTools::Output - A module to manage CracTools output files.
+
+=head1 VERSION
+
+version 1.031
+
+=head1 SYNOPSIS
+
+  # Creating a default output object.
+  # Everything will be print to the standard output
+  my $output = CracTools::Output->new();
+  
+  # Print nice headers
+  my $output->printHeaders(version => '1.01',summary => 'blabla', args => @ARGV);
+  
+  # This will print "foo\tbar\n"
+  $output->printLine('foo','bar');
+  
+  # Using semicolon as separator charcater
+  my $output = CracTools::Output->new(sep => ';');
+  
+  # Print into a file
+  my $output = CracTools::Output->new(file => 'foo.bar');
+
+=head1 DESCRIPTION
+
+CracTools::Output is a simple tool to generate Char-Separated files.
+
+=head1 METHODS
+
+=head2 new
+
+  Arg [sep]  : (Optional) Character to use as separator for columns
+  Arg [file] : (Optional) String - Ouput file, if not specified
+               CracTools::Output prints to STDOUT.
+
+  Example     : $output = CracTools::Output->new(file => 'output.txt', sep => '\t');
+  Description : Create a new CracTools::Output object
+  ReturnType  : CracTools::Output
+
+=head2 printHeaders
+
+  Arg [version]  : (Optional) Version number of the script that is calling "printHeaders" method.
+  Arg [summary]  : (Optional) String - Summary text to print in headers (can have multiple lines
+
+  Example     : $output->printHeaders(version => $version, summary => "Found $n reads");
+  Description : Print headers to the output stream with CracTools-core version, date, name of calling script.
+
+=head2 printHeaderLine
+
+  Arg [1] : Array of strings
+
+  Example     : $output->printHeaderLine("Read Id","Read_seq","Nb_occ");
+  Description : Print header line to the file (with a "# " append to the start of the line)
+
+=head2 printLine
+
+  Arg [1] : Array of strings
+
+  Example     : $output->printLine("Read Id","Read_seq","Nb_occ");
+  Description : Print a line to the file, each string of the array parameter is print
+                with the separator defined for the output.
+
+=head2 printOutput
+
+  Arg [1] : String - Value to print
+
+  Example     : $output->printLine("This is a line");
+  Description : Print the string in parameter to the output stream.
+
+=head2 printlnOutput
+
+  Arg [1] : String - Value to print
+
+  Example     : $output->printLine("This is a line");
+  Description : Print the string in parameter to the output stream with an extra "\n" at the end of the string.
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Nicolas PHILIPPE <nicolas.philippe@inserm.fr>
+
+=item *
+
+Jérôme AUDOUX <jaudoux@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2014 by IRB/INSERM (Institut de Recherche en Biothérapie / Institut National de la Santé et de la Recherche Médicale).
+
+This is free software, licensed under:
+
+  CeCILL FREE SOFTWARE LICENSE AGREEMENT, Version 2.1 dated 2013-06-21
+
+=cut
